Bubble class
Constructors
-
Bubble({bool shouldBounce = true, bool allowDragToClose = true, bool showCloseButton = false, String? customIconPath})
-
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
startBubbleHead({bool sendAppToBackground = true, String? iconPath})
→ Future<void>
-
puts app in background and shows floaty-bubble head
-
startBubbleWidget({bool sendAppToBackground = true, Map<String, dynamic>? widgetData, String template = BubbleWidgetTemplate.medium})
→ Future<void>
-
Puts app in background and shows a floating widget overlay.
-
startLocationUpdates({required String httpsUrl, Duration interval = const Duration(seconds: 15), Map<String, dynamic>? metadata, int maxQueueSize = 200, Duration initialBackoff = const Duration(seconds: 3), Duration maxBackoff = const Duration(seconds: 60), String? authRefreshUrl, Map<String, dynamic>? authRefreshBody, String authTokenResponseKey = 'accessToken', })
→ Future<void>
-
Starts periodic background location uploads to the configured HTTPS endpoint.
-
stopBubbleHead()
→ Future<void>
-
closes floaty-bubble head
-
stopBubbleWidget()
→ Future<void>
-
Alias for stopping the floating widget overlay.
-
stopLocationUpdates()
→ Future<void>
-
Stops background location uploads started by startLocationUpdates.
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateBubbleWidgetData(Map<String, dynamic> widgetData, {String? template})
→ Future<void>
-
Updates dynamic content of the active floating widget overlay.